#line 2 "scantl.cc"

#line 4 "scantl.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer tlyy_create_buffer
#define yy_delete_buffer tlyy_delete_buffer
#define yy_flex_debug tlyy_flex_debug
#define yy_init_buffer tlyy_init_buffer
#define yy_flush_buffer tlyy_flush_buffer
#define yy_load_buffer_state tlyy_load_buffer_state
#define yy_switch_to_buffer tlyy_switch_to_buffer
#define yyin tlyyin
#define yyleng tlyyleng
#define yylex tlyylex
#define yylineno tlyylineno
#define yyout tlyyout
#define yyrestart tlyyrestart
#define yytext tlyytext
#define yywrap tlyywrap
#define yyalloc tlyyalloc
#define yyrealloc tlyyrealloc
#define yyfree tlyyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE tlyyrestart(tlyyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t tlyyleng;

extern FILE *tlyyin, *tlyyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up tlyytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up tlyytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via tlyyrestart()), so that the user can continue scanning by
	 * just pointing tlyyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when tlyytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t tlyyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow tlyywrap()'s to do buffer switches
 * instead of setting up a fresh tlyyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void tlyyrestart (FILE *input_file  );
void tlyy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE tlyy_create_buffer (FILE *file,int size  );
void tlyy_delete_buffer (YY_BUFFER_STATE b  );
void tlyy_flush_buffer (YY_BUFFER_STATE b  );
void tlyypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void tlyypop_buffer_state (void );

static void tlyyensure_buffer_stack (void );
static void tlyy_load_buffer_state (void );
static void tlyy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER tlyy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE tlyy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE tlyy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE tlyy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *tlyyalloc (yy_size_t  );
void *tlyyrealloc (void *,yy_size_t  );
void tlyyfree (void *  );

#define yy_new_buffer tlyy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        tlyyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            tlyy_create_buffer(tlyyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        tlyyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            tlyy_create_buffer(tlyyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define tlyywrap() 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *tlyyin = (FILE *) 0, *tlyyout = (FILE *) 0;

typedef int yy_state_type;

extern int tlyylineno;

int tlyylineno = 1;

extern char *tlyytext;
#define yytext_ptr tlyytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up tlyytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	tlyyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 72
#define YY_END_OF_BUFFER 73
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[242] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    2,    2,    0,    0,   73,   71,   57,   57,
       22,   62,   44,    8,   17,   29,   42,   71,   58,   71,
       21,   20,   28,   27,   71,   71,   48,   49,   54,   51,
       58,   50,   53,   52,   71,   71,   45,   58,   58,   12,
       42,   19,   71,   71,   71,   60,   48,   49,   54,   51,
       60,   50,   53,   52,   60,   60,   11,   11,   11,    9,
       10,   11,   16,   16,   16,   16,   13,   15,   41,   40,
       71,   71,   39,   38,   71,   71,   63,   70,   69,    2,
        2,    5,    5,    4,    3,   68,   57,   57,   65,   64,

       68,   71,   57,   43,   52,    0,   46,   58,    1,    0,
        0,   48,   55,   56,   46,   59,    0,   58,   32,    0,
        0,    0,   36,   49,    0,   42,   58,   58,    0,    0,
        0,    0,   18,   22,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   60,   60,   60,   60,   11,
       11,    1,   16,   16,    1,    0,   14,   40,   39,    0,
       70,    2,    2,    5,    6,    6,    5,    4,    4,    7,
        3,   68,   57,   57,   66,   66,   65,    1,   67,    0,
       47,   47,    0,    0,    0,   59,    0,   58,   30,   31,
        0,   37,   35,    0,    0,    0,    0,    0,    0,   58,

       45,    0,   23,   25,    0,    0,    0,   23,   45,   25,
       60,   61,   60,   60,   45,   41,    0,    0,    0,    0,
        0,   24,   26,    0,    0,    0,    0,   20,   33,   34,
        0,    0,    0,    0,   58,   20,   60,   21,   21,   21,
        0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    7,    1,    8,    1,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   18,   19,
       19,   19,   19,   19,   19,   19,   19,   20,   21,   22,
       23,   24,    1,    1,   25,   26,   26,   26,   27,   28,
       29,   26,   26,   26,   26,   30,   31,   26,   26,   26,
       26,   32,   33,   34,   35,   36,   37,   38,   26,   26,
       39,   40,   41,   42,   26,    1,   25,   26,   26,   26,

       43,   44,   26,   26,   45,   26,   26,   30,   26,   46,
       47,   26,   26,   48,   33,   49,   50,   26,   26,   51,
       26,   26,   52,   53,   54,   55,    1,    1,    1,    1,
        1,   56,   57,   58,   59,   60,    1,   61,   62,    1,
        1,    1,    1,    1,    1,   63,    1,   64,   65,   66,
       67,    1,   68,    1,    1,   69,    1,    1,   70,    1,
       71,   72,    1,   73,    1,   74,   75,   76,   77,   78,
        1,   79,    1,    1,   80,    1,    1,    1,    1,    1,
        1,   81,    1,    1,   82,    1,   83,    1,    1,    1,
        1,    1,    1,   84,    1,    1,    1,    1,    1,    1,

        1,    1,    1,   85,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   86,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[87] =
    {   0,
        1,    1,    2,    3,    1,    4,    1,    1,    5,    5,
        6,    1,    1,    1,    7,    6,    7,    7,    7,    1,
        1,    1,    1,    1,    7,    7,    7,    8,    8,    7,
        7,    7,    7,    7,    7,    7,    7,    8,    1,    4,
        1,    1,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    9,    1,    9,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[260] =
    {   0,
        0,    0,   72,    0,  122,  124,  126,  133,  186,  234,
      282,    0,  141,  144,  160,  167,  591,  592,   86,   88,
      592,  592,  582,  579,  592,  592,  592,  127,    0,  119,
      592,  592,  592,  592,  144,  157,  173,   75,    0,    0,
       63,    0,    0,   95,  201,  572,  592,  562,  539,  592,
      142,  206,  506,   97,  197,    0,  559,  592,  592,  592,
      129,  592,  592,  592,  558,  535,    0,  194,  214,  592,
      592,  570,    0,  216,  220,  569,  592,  227,  592,  592,
      564,  567,  221,  592,  531,  529,  592,    0,    0,    0,
      223,  241,  230,  168,  564,    0,  258,  269,  265,  592,

      563,    0,  275,  592,  592,  549,  592,    0,  561,  158,
      547,  266,  592,  592,  592,    0,  540,  231,  528,  527,
      196,  279,  592,  272,  204,  592,  537,  518,  268,  541,
      235,  297,  592,  592,  260,  240,  260,  499,  507,  491,
      280,  489,  240,  501,  490,  312,  316,  318,  333,    0,
      362,  547,    0,  365,  533,  367,  592,  592,  356,  493,
        0,    0,  374,  376,  533,  531,  523,  285,  369,  592,
      515,    0,  380,  384,  515,  513,  508,  498,  592,  484,
      592,  592,  329,  468,  330,    0,  406,  363,  592,  592,
      414,  592,  395,  393,  335,  409,  333,  369,  349,  396,

        0,  388,  592,  592,  321,  294,  312,  592,  592,  592,
      367,    0,  370,  381,  373,  592,  351,  303,  244,  243,
      190,  592,  592,  131,  123,  334,  377,    0,  592,  592,
      126,   76,   74,  336,  380,  393,  397,  592,    0,  399,
      592,  440,  449,  458,  467,  476,  479,   89,  487,  496,
      498,  506,  515,  524,  533,  542,  545,  547,  549
    } ;

static yyconst flex_int16_t yy_def[260] =
    {   0,
      241,    1,    1,    3,  242,  242,  243,  243,  244,  244,
      244,   11,  245,  245,  246,  246,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  247,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  247,  247,
      247,  247,  247,  241,  241,  241,  241,  247,  247,  241,
      241,  241,  241,  241,  241,  248,  241,  241,  241,  241,
      248,  241,  241,  241,  248,  248,  249,  249,  249,  241,
      241,  249,  250,  250,  250,  250,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  251,  251,  252,
      252,  241,  241,  253,  254,  255,  255,  241,  241,  241,

      255,  256,  241,  241,  241,  241,  241,  247,  241,  241,
      241,  241,  241,  241,  241,  257,  241,  247,  241,  241,
      241,  241,  241,  241,  241,  241,  247,  247,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  258,  258,  258,  258,  249,
      249,  249,  250,  250,  250,  241,  241,  241,  241,  241,
      251,  252,  252,  241,  241,  241,  241,  253,  253,  241,
      254,  255,  255,  241,  241,  241,  241,  255,  241,  241,
      241,  241,  241,  241,  241,  257,  241,  247,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  247,

      247,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      258,  259,  258,  258,  258,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  247,  241,  241,
      241,  241,  241,  241,  247,  258,  258,  241,  247,  258,
        0,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241
    } ;

static yyconst flex_int16_t yy_nxt[679] =
    {   0,
       18,   19,   20,   18,   21,   22,   18,   23,   24,   25,
       26,   27,   18,   28,   29,   30,   31,   32,   18,   33,
       34,   35,   36,   18,   29,   29,   29,   37,   38,   29,
       39,   40,   29,   41,   42,   40,   43,   44,   45,   46,
       18,   47,   29,   48,   29,   29,   29,   29,   41,   29,
       49,   50,   51,   52,   21,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   53,   54,   55,   56,  103,  103,  103,
      103,  116,  116,  116,  118,  146,   56,   56,   56,   57,

       58,   56,   59,   60,   56,   61,   62,   60,   63,   64,
      118,  116,  116,  116,   56,   65,   56,   56,   56,   56,
       61,   56,   66,   68,   69,   68,   69,   74,   75,  109,
       70,   71,   70,   71,   74,   75,  210,   72,  208,   72,
      106,   76,   91,   92,   93,   91,   92,   93,   76,  208,
      107,   94,  113,  113,   94,  129,   95,  110,  104,   95,
      147,   97,   98,   99,  130,  100,  111,  112,   97,   98,
       99,  180,  100,  113,  114,  101,  147,   77,  169,   78,
      115,  181,  101,  170,   77,  223,   78,   19,   20,  116,
      116,  116,   79,  222,  126,  151,  151,  117,   80,  102,

       81,   82,   83,   83,   83,   80,  102,  132,  132,  191,
      133,  119,  120,  222,  121,  151,  151,  154,  154,  192,
      122,  154,  154,  123,  163,  103,   84,  131,  156,  156,
       85,  157,  166,  167,   86,   19,   20,  159,  159,  159,
       79,  124,  103,  164,  165,  176,   80,  175,   81,   82,
       83,   83,   83,   80,  135,  136,  137,  138,  139,  173,
      103,  198,  140,  141,  142,  188,  143,  176,  177,  144,
      103,  174,  175,  199,   84,  145,  103,  103,   85,  183,
      188,  202,   86,   19,   20,  195,  125,   87,  184,  193,
      194,  203,  205,  206,  196,  241,   88,   82,  132,  132,

      241,  133,  115,  182,  207,  166,   88,   88,   88,   89,
       89,   88,   89,   89,   88,   88,   89,   89,   89,   89,
      107,  115,  107,  181,   89,   89,   89,   88,   88,   88,
       89,   88,   88,  208,  104,  126,  104,  126,  112,  212,
      212,  105,  221,  212,  212,  212,  212,  214,  231,  212,
      213,  185,  222,  212,  165,  212,  204,  197,  208,  105,
      212,  212,  124,  151,  151,  213,  154,  154,  156,  156,
      212,  157,  159,  159,  159,  163,  103,  103,  164,  169,
      215,  173,  103,  203,  170,  103,  174,  224,  225,  228,
      232,  233,  203,  204,  212,  212,  236,  212,  212,  226,

      212,  212,  234,  238,  212,  228,  239,  212,  212,  212,
      212,  203,  236,  237,  222,  223,  208,  210,  212,  238,
      212,  212,  239,  240,  212,  212,  212,  212,  235,  192,
      212,  192,  210,  230,  212,  229,  212,  192,  227,  240,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   73,
       73,   73,   73,   73,   73,   73,   73,   73,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   96,   96,   96,   96,
       96,   96,   96,   96,   96,  108,  108,  150,  150,  150,
      150,  223,  150,  150,  150,  150,  153,  153,  153,  153,

      153,  153,  153,  153,  161,  161,  162,  181,  178,  162,
      162,  177,  162,  162,  162,  168,  220,  219,  168,  168,
      168,  168,  168,  168,  171,  241,  167,  171,  171,  171,
      171,  171,  171,  172,  218,  217,  216,  172,  172,  172,
      172,  172,  179,  155,  179,  179,  179,  179,  179,  179,
      179,  186,  186,  211,  211,  212,  212,  152,  124,  210,
      112,  124,  112,  209,  204,  201,  200,  190,  189,  187,
      182,  109,  107,  178,  109,  158,  160,  109,  158,  155,
      152,  149,  148,  117,  134,  128,  127,  126,  105,  104,
      241,   17,  241,  241,  241,  241,  241,  241,  241,  241,

      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241
    } ;

static yyconst flex_int16_t yy_chk[679] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    3,   19,   19,   20,
       20,   38,   38,   38,   41,  248,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
       41,   44,   44,   44,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    5,    5,    6,    6,    7,    7,   30,
        5,    5,    6,    6,    8,    8,  233,    5,  232,    6,
       28,    7,   13,   13,   13,   14,   14,   14,    8,  231,
       28,   13,   54,   54,   14,   51,   13,   35,   30,   14,
       61,   15,   15,   15,   51,   15,   35,   35,   16,   16,
       16,  110,   16,   36,   36,   15,   61,    7,   94,    7,
       36,  110,   16,   94,    8,  225,    8,    9,    9,   37,
       37,   37,    9,  224,   51,   68,   68,   37,    9,   15,

        9,    9,    9,    9,    9,    9,   16,   52,   52,  121,
       52,   45,   45,  221,   45,   69,   69,   74,   74,  121,
       45,   75,   75,   45,   91,   91,    9,   51,   78,   78,
        9,   78,   93,   93,    9,   10,   10,   83,   83,   83,
       10,   45,   92,   92,   92,  220,   10,  219,   10,   10,
       10,   10,   10,   10,   55,   55,   55,   55,   55,   97,
       97,  125,   55,   55,   55,  118,   55,   99,   99,   55,
       98,   98,   98,  125,   10,   55,  103,  103,   10,  112,
      118,  129,   10,   11,   11,  124,   45,   11,  112,  122,
      122,  129,  131,  131,  124,  168,   11,   11,  132,  132,

      168,  132,  136,  136,  131,  218,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
      143,  143,  135,  135,   11,   11,   11,   11,   11,   11,
       11,   11,   11,  135,  137,  137,  137,  137,  141,  146,
      146,  141,  183,  147,  147,  148,  148,  148,  195,  146,
      147,  112,  183,  147,  217,  148,  206,  124,  195,  141,
      149,  149,  141,  151,  151,  147,  154,  154,  156,  156,
      149,  156,  159,  159,  159,  163,  163,  164,  164,  169,
      149,  173,  173,  205,  169,  174,  174,  185,  185,  188,
      197,  197,  207,  207,  211,  211,  213,  213,  213,  185,

      215,  215,  197,  227,  211,  188,  235,  213,  214,  214,
      215,  202,  213,  214,  226,  226,  234,  234,  214,  227,
      236,  236,  235,  237,  237,  237,  240,  240,  200,  199,
      236,  198,  196,  194,  237,  193,  240,  191,  187,  237,
      242,  242,  242,  242,  242,  242,  242,  242,  242,  243,
      243,  243,  243,  243,  243,  243,  243,  243,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  246,  246,  246,  246,
      246,  246,  246,  246,  246,  247,  247,  249,  249,  249,
      249,  184,  249,  249,  249,  249,  250,  250,  250,  250,

      250,  250,  250,  250,  251,  251,  252,  180,  178,  252,
      252,  177,  252,  252,  252,  253,  176,  175,  253,  253,
      253,  253,  253,  253,  254,  171,  167,  254,  254,  254,
      254,  254,  254,  255,  166,  165,  160,  255,  255,  255,
      255,  255,  256,  155,  256,  256,  256,  256,  256,  256,
      256,  257,  257,  258,  258,  259,  259,  152,  145,  144,
      142,  140,  139,  138,  130,  128,  127,  120,  119,  117,
      111,  109,  106,  101,   95,   86,   85,   82,   81,   76,
       72,   66,   65,   57,   53,   49,   48,   46,   24,   23,
       17,  241,  241,  241,  241,  241,  241,  241,  241,  241,

      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241,  241,  241,
      241,  241,  241,  241,  241,  241,  241,  241
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int tlyy_flex_debug;
int tlyy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *tlyytext;
#line 1 "scantl.ll"
/* -*- coding: utf-8 -*-
** Copyright (C) 2010, 2011, 2012, 2013, 2014, 2015, Laboratoire de
** Recherche et Développement de l'Epita (LRDE).
** Copyright (C) 2003, 2004  Laboratoire d'Informatique de Paris 6 (LIP6),
** département Systèmes Répartis Coopératifs (SRC), Université Pierre
** et Marie Curie.
**
** This file is part of Spot, a model checking library.
**
** Spot is free software; you can redistribute it and/or modify it
** under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** Spot is distributed in the hope that it will be useful, but WITHOUT
** ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
** or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
** License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#line 30 "scantl.ll"
#include <cstdlib>
#include <string>

#include <spot/parsetl/parsedecl.hh>
#include "spot/priv/trim.hh"

#define YY_USER_ACTION \
  yylloc->columns(tlyyleng);

static int start_token = 0;
static int parent_level = 0;
static bool missing_parent = false;
static bool lenient_mode = false;
static int orig_cond = 0;
static unsigned comment_level = 0;

typedef tlyy::parser::token token;







#line 763 "scantl.cc"

#define INITIAL 0
#define not_prop 1
#define in_par 2
#define in_bra 3
#define sqbracket 4
#define lbt 5
#define in_COMMENT 6
#define in_STRING 7

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int tlyylex_destroy (void );

int tlyyget_debug (void );

void tlyyset_debug (int debug_flag  );

YY_EXTRA_TYPE tlyyget_extra (void );

void tlyyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *tlyyget_in (void );

void tlyyset_in  (FILE * in_str  );

FILE *tlyyget_out (void );

void tlyyset_out  (FILE * out_str  );

yy_size_t tlyyget_leng (void );

char *tlyyget_text (void );

int tlyyget_lineno (void );

void tlyyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int tlyywrap (void );
#else
extern int tlyywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
    static int yy_top_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( tlyytext, tlyyleng, 1, tlyyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( tlyyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( tlyyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, (yy_size_t) max_size, tlyyin)) == 0 && ferror(tlyyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(tlyyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int tlyylex (void);

#define YY_DECL int tlyylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after tlyytext and tlyyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! tlyyin )
			tlyyin = stdin;

		if ( ! tlyyout )
			tlyyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			tlyyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				tlyy_create_buffer(tlyyin,YY_BUF_SIZE );
		}

		tlyy_load_buffer_state( );
		}

	{
#line 70 "scantl.ll"



  if (start_token)
    {
      int t = start_token;
      start_token = 0;
      return t;
    }
  yylloc->step();
  std::string s;


#line 1008 "scantl.cc"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of tlyytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 242 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 241 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 83 "scantl.ll"
{
			  if (YY_START != in_COMMENT)
			    {
                              orig_cond = YY_START;
                              BEGIN(in_COMMENT);
			      comment_level = 0;
			    }
			  ++comment_level;
			}
	YY_BREAK

case 2:
YY_RULE_SETUP
#line 93 "scantl.ll"
continue;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 94 "scantl.ll"
continue;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 95 "scantl.ll"
continue;
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 96 "scantl.ll"
yylloc->lines(tlyyleng); yylloc->end.column = 1;
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 97 "scantl.ll"
yylloc->lines(tlyyleng / 2); yylloc->end.column = 1;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 98 "scantl.ll"
if (--comment_level == 0) BEGIN(orig_cond);
	YY_BREAK
case YY_STATE_EOF(in_COMMENT):
#line 99 "scantl.ll"
{
                           BEGIN(orig_cond);
                           error_list.push_back(
			     spot::one_parse_error(*yylloc,
			       "unclosed comment"));
			   return 0;
                        }
	YY_BREAK

case 8:
YY_RULE_SETUP
#line 108 "scantl.ll"
{
				  if (!lenient_mode)
                                    {
				      BEGIN(0);
				      return token::PAR_OPEN;
                                    }
                                  /* Parse any (...) block as a single block,
				     taking care of nested parentheses.  The
				     parser will then try to parse this block
				     recursively.  */
                                  BEGIN(in_par);
                                  parent_level = 1;
				  yylval->str = new std::string();
                                }
	YY_BREAK

case 9:
YY_RULE_SETUP
#line 123 "scantl.ll"
{
				  ++parent_level;
				  yylval->str->append(tlyytext, tlyyleng);
				}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 127 "scantl.ll"
{
				  if (--parent_level)
				    {
                                      yylval->str->append(tlyytext, tlyyleng);
				    }
				  else
				    {
                                      BEGIN(not_prop);
				      spot::trim(*yylval->str);
				      return token::PAR_BLOCK;
				    }
				}
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 139 "scantl.ll"
yylval->str->append(tlyytext, tlyyleng);
	YY_BREAK
case YY_STATE_EOF(in_par):
#line 140 "scantl.ll"
{
				  unput(')');
				  if (!missing_parent)
                                    error_list.push_back(
				      spot::one_parse_error(*yylloc,
 					"missing closing parenthese"));
				  missing_parent = true;
				}
	YY_BREAK

case 12:
YY_RULE_SETUP
#line 150 "scantl.ll"
{
				  if (!lenient_mode)
				  {
				     BEGIN(0);
			             return token::BRACE_OPEN;
                                  }
                                  /* Parse any {...} block as a single block,
				     taking care of nested parentheses.  The
				     parser will then try to parse this block
				     recursively.  */
                                  BEGIN(in_bra);
                                  parent_level = 1;
				  yylval->str = new std::string();
                                }
	YY_BREAK

case 13:
YY_RULE_SETUP
#line 165 "scantl.ll"
{
				  ++parent_level;
				  yylval->str->append(tlyytext, tlyyleng);
				}
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 169 "scantl.ll"
{
				  if (--parent_level)
				    {
                                      yylval->str->append(tlyytext, tlyyleng);
				    }
				  else
				    {
                                      BEGIN(not_prop);
				      spot::trim(*yylval->str);
				      return token::BRA_BANG_BLOCK;
				    }
                                }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 181 "scantl.ll"
{
				  if (--parent_level)
				    {
                                      yylval->str->append(tlyytext, tlyyleng);
				    }
				  else
				    {
                                      BEGIN(not_prop);
				      spot::trim(*yylval->str);
				      return token::BRA_BLOCK;
				    }
				}
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 193 "scantl.ll"
yylval->str->append(tlyytext, tlyyleng);
	YY_BREAK
case YY_STATE_EOF(in_bra):
#line 194 "scantl.ll"
{
				  unput(')');
				  if (!missing_parent)
                                    error_list.push_back(
				      spot::one_parse_error(*yylloc,
 					"missing closing brace"));
				  missing_parent = true;
				}
	YY_BREAK

case 17:
YY_RULE_SETUP
#line 204 "scantl.ll"
BEGIN(not_prop); return token::PAR_CLOSE;
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 205 "scantl.ll"
BEGIN(not_prop); return token::BRACE_BANG_CLOSE;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 206 "scantl.ll"
BEGIN(not_prop); return token::BRACE_CLOSE;
	YY_BREAK
/* Must go before the other operators, because the F of FALSE
     should not be mistaken with a unary F. */
case 20:
YY_RULE_SETUP
#line 210 "scantl.ll"
BEGIN(0); return token::CONST_TRUE;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 211 "scantl.ll"
BEGIN(0); return token::CONST_FALSE;
	YY_BREAK
/* ~ comes from Goal, ! from everybody else */
case 22:
YY_RULE_SETUP
#line 215 "scantl.ll"
BEGIN(0); return token::OP_NOT;
	YY_BREAK
/* PSL operators */
case 23:
YY_RULE_SETUP
#line 218 "scantl.ll"
BEGIN(0); return token::OP_UCONCAT;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 219 "scantl.ll"
BEGIN(0); return token::OP_ECONCAT;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 220 "scantl.ll"
BEGIN(0); return token::OP_UCONCAT_NONO;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 221 "scantl.ll"
BEGIN(0); return token::OP_ECONCAT_NONO;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 222 "scantl.ll"
BEGIN(0); return token::OP_CONCAT;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 223 "scantl.ll"
BEGIN(0); return token::OP_FUSION;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 224 "scantl.ll"
BEGIN(0); return token::OP_STAR;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 225 "scantl.ll"
BEGIN(0); return token::OP_BSTAR;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 226 "scantl.ll"
BEGIN(0); return token::OP_PLUS;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 227 "scantl.ll"
BEGIN(sqbracket); return token::OP_STAR_OPEN;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 228 "scantl.ll"
BEGIN(0); return token::OP_BFSTAR;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 229 "scantl.ll"
BEGIN(0); return token::OP_FPLUS;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 230 "scantl.ll"
BEGIN(sqbracket); return token::OP_FSTAR_OPEN;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 231 "scantl.ll"
BEGIN(sqbracket); return token::OP_EQUAL_OPEN;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 232 "scantl.ll"
BEGIN(sqbracket); return token::OP_GOTO_OPEN;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 233 "scantl.ll"
BEGIN(0); return token::OP_SQBKT_CLOSE;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 234 "scantl.ll"
{
				  errno = 0;
				  unsigned long n = strtoul(tlyytext, 0, 10);
                                  yylval->num = n;
				  if (errno || yylval->num != n)
				    {
                                      error_list.push_back(
				        spot::one_parse_error(*yylloc,
					  "value too large ignored"));
				      // Skip this number and read next token
                                      yylloc->step();
                                    }
				  else
                                    {
                                      return token::OP_SQBKT_NUM;
                                    }
				}
	YY_BREAK
/* .. is from PSL and EDL
   : is from Verilog and PSL
   to is from VHDL
   , is from Perl */
case 40:
YY_RULE_SETUP
#line 255 "scantl.ll"
return token::OP_SQBKT_SEP;
	YY_BREAK
/* In SVA you use [=1:$] instead of [=1..].  We will also accept
     [=1..$] and [=1:].  The PSL LRM shows examples like [=1:inf]
     instead, so will accept this too.  */
case 41:
YY_RULE_SETUP
#line 260 "scantl.ll"
return token::OP_UNBOUNDED;
	YY_BREAK
/* & and | come from Spin.  && and || from LTL2BA.
     /\, \/, and xor are from LBTT.
     --> and <--> come from Goal.
     +,*,^ are from Wring. */
case 42:
YY_RULE_SETUP
#line 266 "scantl.ll"
BEGIN(0); return token::OP_OR;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 267 "scantl.ll"
BEGIN(0); return token::OP_AND;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 268 "scantl.ll"
BEGIN(0); return token::OP_SHORT_AND;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 269 "scantl.ll"
BEGIN(0); return token::OP_XOR;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 270 "scantl.ll"
BEGIN(0); return token::OP_IMPLIES;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 271 "scantl.ll"
BEGIN(0); return token::OP_EQUIV;
	YY_BREAK
/* <>, [], and () are used in Spin.  */
case 48:
YY_RULE_SETUP
#line 274 "scantl.ll"
BEGIN(0); return token::OP_F;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 275 "scantl.ll"
BEGIN(0); return token::OP_G;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 276 "scantl.ll"
BEGIN(0); return token::OP_U;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 277 "scantl.ll"
BEGIN(0); return token::OP_R;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 278 "scantl.ll"
BEGIN(0); return token::OP_X;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 279 "scantl.ll"
BEGIN(0); return token::OP_W;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 280 "scantl.ll"
BEGIN(0); return token::OP_M;
	YY_BREAK
/* The combining overline or macron (overbar) should normally
     occur only after a single letter, but we do not check that. */
case 55:
YY_RULE_SETUP
#line 284 "scantl.ll"
return token::OP_POST_NEG;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 285 "scantl.ll"
return token::OP_POST_POS;
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
#line 287 "scantl.ll"
/* discard whitespace */ yylloc->step ();
	YY_BREAK
/* An Atomic proposition cannot start with the letter
     used by a unary operator (F,G,X), unless this
     letter is followed by a digit in which case we assume
     it's an ATOMIC_PROP (even though F0 could be seen as Ffalse, we
     don't, because Ffalse is never used in practice).
  */
case 58:
#line 296 "scantl.ll"
case 59:
#line 297 "scantl.ll"
/*
     However if we have just parsed an atomic proposition, then we are
     not expecting another atomic proposition, so we can be stricter
     and disallow propositions that start with M, U, R, V, and W.  If
     you wonder why we do this, consider the Wring formula `p=0Uq=1'.
     When p is parsed, we enter the not_prop start condition, we
     remain into this condition when `=0' is processed, and then
     because we are in this condition we will not consider `Uq' as an
     atomic proposition but as a `U' operator followed by a `q' atomic
     proposition.

     We also disable atomic proposition that may look like a combination
     of a binary operator followed by several unary operators.
     E.g. UFXp.   This way, `p=0UFXp=1' will be parsed as `(p=0)U(F(X(p=1)))'.
  */
case 60:
#line 313 "scantl.ll"
case 61:
YY_RULE_SETUP
#line 313 "scantl.ll"
{
			  yylval->str = new std::string(tlyytext, tlyyleng);
			  BEGIN(not_prop);
			  return token::ATOMIC_PROP;
			}
	YY_BREAK
/* Atomic propositions can also be enclosed in double quotes.

     orig_cond stores the parsing condition to use after the
     string has been parsed. */
case 62:
YY_RULE_SETUP
#line 323 "scantl.ll"
{
                          orig_cond = not_prop;
			  BEGIN(in_STRING);
			}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 327 "scantl.ll"
{
			  orig_cond = lbt;
			  BEGIN(in_STRING);
			}
	YY_BREAK

case 64:
YY_RULE_SETUP
#line 333 "scantl.ll"
{
                           BEGIN(orig_cond);
			   yylval->str = new std::string(s);
			   return token::ATOMIC_PROP;
 			}
	YY_BREAK
case 65:
/* rule 65 can match eol */
YY_RULE_SETUP
#line 338 "scantl.ll"
{
  			  s.append(tlyytext, tlyyleng);
                          yylloc->lines(tlyyleng); yylloc->end.column = 1;
			}
	YY_BREAK
case 66:
/* rule 66 can match eol */
YY_RULE_SETUP
#line 342 "scantl.ll"
{
  			  s.append(tlyytext, tlyyleng);
                          yylloc->lines(tlyyleng / 2); yylloc->end.column = 1;
			}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 346 "scantl.ll"
s += tlyytext[1];
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 347 "scantl.ll"
s.append(tlyytext, tlyyleng);
	YY_BREAK
case YY_STATE_EOF(in_STRING):
#line 348 "scantl.ll"
{
                           error_list.push_back(
			     spot::one_parse_error(*yylloc,
			       "unclosed string"));
                           BEGIN(orig_cond);
			   yylval->str = new std::string(s);
			   return token::ATOMIC_PROP;
                        }
	YY_BREAK

/* these are operators */
case 69:
YY_RULE_SETUP
#line 359 "scantl.ll"
return *tlyytext;
	YY_BREAK
/* in LBT's format, atomic proposition look like p0 or p3141592, but
     for compatibility with ltl2dstar we also accept any alphanumeric
     string that is not an operator. */
case 70:
YY_RULE_SETUP
#line 363 "scantl.ll"
{
			  yylval->str = new std::string(tlyytext, tlyyleng);
			  return token::ATOMIC_PROP;
			}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 369 "scantl.ll"
return *tlyytext;
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(not_prop):
case YY_STATE_EOF(sqbracket):
case YY_STATE_EOF(lbt):
#line 371 "scantl.ll"
return token::END_OF_INPUT;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 373 "scantl.ll"
ECHO;
	YY_BREAK
#line 1638 "scantl.cc"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed tlyyin at a new source and called
			 * tlyylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = tlyyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( tlyywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * tlyytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of tlyylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					tlyyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			tlyyrestart(tlyyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) tlyyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 242 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 242 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 241);

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up tlyytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					tlyyrestart(tlyyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( tlyywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve tlyytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void tlyyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        tlyyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            tlyy_create_buffer(tlyyin,YY_BUF_SIZE );
	}

	tlyy_init_buffer(YY_CURRENT_BUFFER,input_file );
	tlyy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void tlyy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		tlyypop_buffer_state();
	 *		tlyypush_buffer_state(new_buffer);
     */
	tlyyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	tlyy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (tlyywrap()) processing, but the only time this flag
	 * is looked at is after tlyywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void tlyy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	tlyyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE tlyy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) tlyyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in tlyy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) tlyyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in tlyy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	tlyy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with tlyy_create_buffer()
 * 
 */
    void tlyy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		tlyyfree((void *) b->yy_ch_buf  );

	tlyyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a tlyyrestart() or at EOF.
 */
    static void tlyy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	tlyy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then tlyy_init_buffer was _probably_
     * called from tlyyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void tlyy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		tlyy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void tlyypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	tlyyensure_buffer_stack();

	/* This block is copied from tlyy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from tlyy_switch_to_buffer. */
	tlyy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void tlyypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	tlyy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		tlyy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void tlyyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)tlyyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in tlyyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)tlyyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in tlyyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE tlyy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) tlyyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in tlyy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	tlyy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to tlyylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       tlyy_scan_bytes() instead.
 */
YY_BUFFER_STATE tlyy_scan_string (yyconst char * yystr )
{
    
	return tlyy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to tlyylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE tlyy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) tlyyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in tlyy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = tlyy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in tlyy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) tlyyalloc(new_size  );

		else
			(yy_start_stack) = (int *) tlyyrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up tlyytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		tlyytext[tlyyleng] = (yy_hold_char); \
		(yy_c_buf_p) = tlyytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		tlyyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int tlyyget_lineno  (void)
{
        
    return tlyylineno;
}

/** Get the input stream.
 * 
 */
FILE *tlyyget_in  (void)
{
        return tlyyin;
}

/** Get the output stream.
 * 
 */
FILE *tlyyget_out  (void)
{
        return tlyyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t tlyyget_leng  (void)
{
        return tlyyleng;
}

/** Get the current token.
 * 
 */

char *tlyyget_text  (void)
{
        return tlyytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void tlyyset_lineno (int  line_number )
{
    
    tlyylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see tlyy_switch_to_buffer
 */
void tlyyset_in (FILE *  in_str )
{
        tlyyin = in_str ;
}

void tlyyset_out (FILE *  out_str )
{
        tlyyout = out_str ;
}

int tlyyget_debug  (void)
{
        return tlyy_flex_debug;
}

void tlyyset_debug (int  bdebug )
{
        tlyy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from tlyylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    tlyyin = stdin;
    tlyyout = stdout;
#else
    tlyyin = (FILE *) 0;
    tlyyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * tlyylex_init()
     */
    return 0;
}

/* tlyylex_destroy is for both reentrant and non-reentrant scanners. */
int tlyylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		tlyy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		tlyypop_buffer_state();
	}

	/* Destroy the stack itself. */
	tlyyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        tlyyfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * tlyylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *tlyyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *tlyyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void tlyyfree (void * ptr )
{
	free( (char *) ptr );	/* see tlyyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 372 "scantl.ll"



void
flex_set_buffer(const std::string& buf,
		int start_tok, bool lenient)
{
  tlyypush_buffer_state(YY_CURRENT_BUFFER);
  (void) tlyy_scan_bytes(buf.c_str(),buf.size());
  start_token = start_tok;
  if (start_tok == token::START_LBT)
    yy_push_state(lbt);
  else
    yy_push_state(0);
  lenient_mode = lenient;
}

void
flex_unset_buffer()
{
  (void)&yy_top_state; // shut up a g++ warning.
  yy_pop_state();
  tlyypop_buffer_state();
  missing_parent = false;
}

